<?php
/**
 * video functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Video
 */


/*********************************************************************************************************
* Basics
**********************************************************************************************************/

if ( ! function_exists( 'seos_video_setup' ) ) :

function seos_video_setup() {

	load_theme_textdomain( 'seos-video', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
			
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'seos-video' ),
	) );
	
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );


	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'seos_video_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'seos_video_setup' );
	
function seos_video_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'seos_video_content_width', 640 );
}
add_action( 'after_setup_theme', 'seos_video_content_width', 0 );

/**
 * Register widget area.
 */
function seos_video_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'seos-video' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'seos-video' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
		
}

add_action( 'widgets_init', 'seos_video_widgets_init' );

/************************** Includes ******************************/

		require get_template_directory() . '/inc/custom-header.php';
		require get_template_directory() . '/inc/template-tags.php';
		require get_template_directory() . '/inc/extras.php';
		require get_template_directory() . '/inc/customizer.php';
		require get_template_directory() . '/inc/jetpack.php';
	
/**
 * Enqueue scripts and styles.
 */
function seos_video_scripts() {
	wp_enqueue_style( 'seos-video-style', get_stylesheet_uri() );
	
	// Add Genericons, used in the main stylesheet.
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), '3.4.1' );
	
	wp_enqueue_style( 'seos_video_animation_menu', get_template_directory_uri() . '/css/bounceInUp.css');
	
	wp_enqueue_style( 'seos_video_animata_css', get_template_directory_uri() . '/css/animate.css');
		
	wp_enqueue_style( 'seos_video_scroll_effect_css', get_template_directory_uri() . '/css/scroll-effect.css');

	wp_enqueue_script( 'seos-video-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'seos-video-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'seos_video_scripts' );


function seos_video_admin_scripts() {

	wp_enqueue_style( 'seos_video_admin', get_template_directory_uri() . '/css/admin.css');

}

add_action( 'admin_enqueue_scripts', 'seos_video_admin_scripts' );


/*********************************************************************************************************
* Excerpt
**********************************************************************************************************/
	
function seos_video_excerpt_more( $seos_video_link ) {
	if ( is_admin() ) {
		return $seos_video_link;
	}

	$seos_video_link = sprintf( '<p class="link-more"><a href="%1$s" class="read-more">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Read More<span class="screen-reader-text"> "%s"</span>', 'seos-video' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $seos_video_link;
}
add_filter( 'excerpt_more', 'seos_video_excerpt_more' );

/***********************************************************************************
 * Seos Video Buy
***********************************************************************************/

		function magazine_news_support($wp_customize){
			class magazine_news_Customize extends WP_Customize_Control {
				public function render_content() { ?>
				<div class="seos_video-info"> 
					<div class="button media-button button-primary button-large media-button-select">
						<a class="sv-info" href="<?php echo esc_url( 'https://seosthemes.com/free-wordpress-video-theme/' ); ?>" title="<?php esc_attr_e( 'Seos Video Buy', 'seos-video' ); ?>" target="_blank">
						<?php _e( 'Seos Video Buy Premium', 'seos-video' ); ?>
						</a>
					</div>
				</div>
				<?php
				}
			}
		}
		add_action('customize_register', 'magazine_news_support');

		function customize_styles_magazine_news( $input ) { ?>
			<style type="text/css">
				#customize-theme-controls #accordion-section-seos_video_buy_section .accordion-section-title,
				#customize-theme-controls #accordion-section-seos_video_buy_section > .accordion-section-title {
					background: #555555;
					color: #FFFFFF;
				}

				.magazine_news-info button a {
					color: #FFFFFF;
				}	
			</style>
		<?php }
		
		add_action( 'customize_controls_print_styles', 'customize_styles_magazine_news');

		if ( ! function_exists( 'seos_video_buy' ) ) :
			function seos_video_buy( $wp_customize ) {
			$wp_customize->add_section( 'seos_video_buy_section', array(
				'title'			=> __('Seos Video Buy Premium', 'seos-video'),
				'description'	=> __('	Learn more about Seos Video. ','seos-video'),
				'priority'		=> 3,
			));
			$wp_customize->add_setting( 'seos_video_setting', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new magazine_news_Customize(
					$wp_customize,'seos_video_setting', array(
						'label'		=> __('Seos Video Buy Premium', 'seos-video'),
						'section'	=> 'seos_video_buy_section',
						'settings'	=> 'seos_video_setting',
					)
				)
			);
		}
		endif;
		 
		add_action('customize_register', 'seos_video_buy');